"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime/helpers/inherits"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime/helpers/possibleConstructorReturn"));

var _getPrototypeOf2 = _interopRequireDefault(require("@babel/runtime/helpers/getPrototypeOf"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _link = _interopRequireDefault(require("@govuk-react/link"));

var _card = require("./card");

var _itemRenderers = require("./card/item-renderers");

var _constants = require("../constants");

var _CardUtils = _interopRequireDefault(require("./card/CardUtils"));

var _DateUtils = _interopRequireDefault(require("../../utils/DateUtils"));

var _NumberUtils = _interopRequireDefault(require("../../utils/NumberUtils"));

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0, _getPrototypeOf2["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0, _getPrototypeOf2["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0, _possibleConstructorReturn2["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var TITLES = {
  add: 'New investment project added'
};

var InvestmentProject = /*#__PURE__*/function (_React$PureComponent) {
  (0, _inherits2["default"])(InvestmentProject, _React$PureComponent);

  var _super = _createSuper(InvestmentProject);

  function InvestmentProject() {
    (0, _classCallCheck2["default"])(this, InvestmentProject);
    return _super.apply(this, arguments);
  }

  (0, _createClass2["default"])(InvestmentProject, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          activity = _this$props.activity,
          showDetails = _this$props.showDetails,
          showDnbHierarchy = _this$props.showDnbHierarchy;

      var company = _CardUtils["default"].getCompany(activity);

      var type = (0, _lodash.get)(activity, 'type');
      var title = TITLES[type.toLowerCase()];
      var url = (0, _lodash.get)(activity, 'object.url');
      var name = (0, _lodash.get)(activity, 'object.name');
      var investmentType = (0, _lodash.get)(activity, 'object.dit:investmentType.name');

      var adviser = _CardUtils["default"].getAdviser(activity);

      var estimatedLandDate = _DateUtils["default"].format((0, _lodash.get)(activity, 'object.dit:estimatedLandDate'));

      var contacts = _CardUtils["default"].getContacts(activity); // Specific to Foreign direct investment (FDI) only


      var totalInvestment = _NumberUtils["default"].currencyGBP((0, _lodash.get)(activity, 'object.dit:totalInvestment'));

      var foreignEquityInvestment = _NumberUtils["default"].currencyGBP((0, _lodash.get)(activity, 'object.dit:foreignEquityInvestment'));

      var grossValueAdded = _NumberUtils["default"].currencyGBP((0, _lodash.get)(activity, 'object.dit:grossValueAdded'));

      var numberNewJobs = _NumberUtils["default"].decimal((0, _lodash.get)(activity, 'object.dit:numberNewJobs'));

      var published = (0, _lodash.get)(activity, 'published');
      return /*#__PURE__*/_react["default"].createElement(_card.Card, null, /*#__PURE__*/_react["default"].createElement(_card.CardHeader, {
        company: showDnbHierarchy ? company : null,
        heading: /*#__PURE__*/_react["default"].createElement(_link["default"], {
          href: url
        }, name),
        startTime: published,
        blockText: "".concat(title, " - ").concat(investmentType)
      }), /*#__PURE__*/_react["default"].createElement(_card.CardDetails, {
        summary: "Key details and people for this project",
        link: {
          url: url,
          text: 'Go to the investment project detail page'
        },
        showDetails: showDetails
      }, /*#__PURE__*/_react["default"].createElement(_card.CardTable, {
        rows: [{
          header: 'Investment Type',
          content: investmentType
        }, {
          header: 'Added by',
          content: adviser ? /*#__PURE__*/_react["default"].createElement(_card.CardDetailsList, {
            itemRenderer: _itemRenderers.AdviserItemRenderer,
            items: [adviser]
          }) : null
        }, {
          header: 'Estimated land date',
          content: estimatedLandDate
        }, {
          header: 'Company contact(s)',
          content: /*#__PURE__*/_react["default"].createElement(_card.CardDetailsList, {
            itemRenderer: _itemRenderers.ContactItemRenderer,
            items: contacts
          })
        }, {
          header: 'Total Investment',
          content: totalInvestment
        }, {
          header: 'Capital expenditure value',
          content: foreignEquityInvestment
        }, {
          header: 'Gross value added (GVA)',
          content: grossValueAdded
        }, {
          header: 'Number of new jobs',
          content: numberNewJobs
        }]
      })));
    }
  }], [{
    key: "canRender",
    value: function canRender(activity) {
      return _CardUtils["default"].canRenderByTypes(activity, _constants.ACTIVITY_TYPE.InvestmentProject);
    }
  }]);
  return InvestmentProject;
}(_react["default"].PureComponent);

exports["default"] = InvestmentProject;
(0, _defineProperty2["default"])(InvestmentProject, "propTypes", {
  activity: _propTypes["default"].object.isRequired,
  showDetails: _propTypes["default"].bool.isRequired,
  showDnbHierarchy: _propTypes["default"].bool.isRequired
});