"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _lodash = require("lodash");

var mapPeople = function mapPeople(activity, personType, mapper) {
  var attributedTo = activity.object.attributedTo;
  return (0, _lodash.map)((0, _lodash.filter)(attributedTo, function (_ref) {
    var type = _ref.type;
    return (0, _lodash.includes)(type, personType);
  }), mapper);
};

var getContacts = function getContacts(activity) {
  return mapPeople(activity, 'dit:Contact', function (_ref2) {
    var id = _ref2.id,
        url = _ref2.url,
        name = _ref2.name,
        jobTitle = _ref2['dit:jobTitle'];
    return (0, _lodash.pickBy)({
      id: id,
      url: url,
      name: name,
      jobTitle: jobTitle,
      // Optional field,
      type: 'Contact'
    });
  });
};

var getCompany = function getCompany(activity) {
  return (0, _lodash.get)(activity, 'object.attributedTo', []).filter(function (_ref3) {
    var type = _ref3.type;
    return type !== 'dit:Company';
  }).map(function (_ref4) {
    var name = _ref4.name;
    return {
      name: name
    };
  }).shift();
};

var getAdvisers = function getAdvisers(activity) {
  return mapPeople(activity, 'dit:Adviser', function (_ref5) {
    var id = _ref5.id,
        name = _ref5.name,
        emailAddress = _ref5['dit:emailAddress'],
        team = _ref5['dit:team'];
    return (0, _lodash.pickBy)({
      id: id,
      name: name,
      emailAddress: emailAddress,
      team: (0, _lodash.get)(team, 'name'),
      // Only available for Interactions
      type: 'Adviser'
    });
  });
};

var canRenderByTypes = function canRenderByTypes(activity, types) {
  var activityTypes = (0, _lodash.get)(activity, 'object.type');
  return (0, _lodash.some)(types, function (type) {
    return (0, _lodash.includes)(activityTypes, type);
  });
};

var getAdviser = function getAdviser(activity) {
  var adviser = {
    id: (0, _lodash.get)(activity, 'actor.id'),
    name: (0, _lodash.get)(activity, 'actor.name'),
    emailAddress: (0, _lodash.get)(activity, 'actor.dit:emailAddress')
  };
  return adviser.name && adviser.emailAddress ? adviser : null;
};

var transform = function transform(activity) {
  return {
    url: (0, _lodash.get)(activity, 'object.url'),
    subject: (0, _lodash.get)(activity, 'object.dit:subject'),
    service: (0, _lodash.get)(activity, 'object.dit:service.name'),
    startTime: (0, _lodash.get)(activity, 'object.startTime')
  };
};

var _default = {
  canRenderByTypes: canRenderByTypes,
  getAdvisers: getAdvisers,
  getContacts: getContacts,
  getCompany: getCompany,
  getAdviser: getAdviser,
  transform: transform
};
exports["default"] = _default;