"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _govukColours = require("govuk-colours");

var _icons = require("@govuk-react/icons");

var _select = _interopRequireDefault(require("@govuk-react/select"));

var _lodash = require("lodash");

var _button = _interopRequireDefault(require("@govuk-react/button"));

var _constants = require("@govuk-react/constants");

var _formGroup = _interopRequireDefault(require("@govuk-react/form-group"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _useFormContext2 = _interopRequireDefault(require("../hooks/useFormContext"));

var _useAddressSearch2 = _interopRequireDefault(require("../../address-search/useAddressSearch"));

var _usePostcodeLookup = _interopRequireDefault(require("../../address-search/usePostcodeLookup"));

var _FieldInput = _interopRequireDefault(require("./FieldInput"));

var _FieldUneditable = _interopRequireDefault(require("./FieldUneditable"));

var _FieldWrapper = _interopRequireDefault(require("./FieldWrapper"));

var _StatusMessage = _interopRequireDefault(require("../../status-message/StatusMessage"));

function _templateObject() {
  var data = (0, _taggedTemplateLiteral2["default"])(["\n  ", " {\n    max-width: 200px;\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

var UNITED_KINGDOM = 'United Kingdom';
var StyledFieldPostcode = (0, _styledComponents["default"])(_FieldInput["default"])(_templateObject(), _constants.MEDIA_QUERIES.TABLET);

var FieldAddress = function FieldAddress(_ref) {
  var name = _ref.name,
      label = _ref.label,
      legend = _ref.legend,
      hint = _ref.hint,
      country = _ref.country,
      apiEndpoint = _ref.apiEndpoint,
      onSelectUKAddress = _ref.onSelectUKAddress;
  var findAddress = (0, _usePostcodeLookup["default"])(apiEndpoint);

  var _useAddressSearch = (0, _useAddressSearch2["default"])(findAddress),
      onAddressSearch = _useAddressSearch.onAddressSearch,
      isSubmitting = _useAddressSearch.isSubmitting,
      error = _useAddressSearch.error,
      addressList = _useAddressSearch.addressList;

  var _useFormContext = (0, _useFormContext2["default"])(),
      postcode = _useFormContext.values.postcode,
      setFieldValue = _useFormContext.setFieldValue,
      validateForm = _useFormContext.validateForm,
      setIsLoading = _useFormContext.setIsLoading;

  (0, _react.useEffect)(function () {
    return setIsLoading(isSubmitting);
  }, [isSubmitting]);
  var isUK = country.name === UNITED_KINGDOM;

  function onSearchClick(e) {
    e.preventDefault();
    return (0, _lodash.isEmpty)(validateForm(['postcode'])) ? onAddressSearch(postcode) : null;
  }

  var onAddressSelect = function onAddressSelect(evt) {
    var index = evt.target.selectedIndex;

    if (index === 0) {
      return;
    }

    var address = addressList[index];
    setFieldValue('postcode', address.postcode);
    setFieldValue('address1', address.address1);
    setFieldValue('address2', address.address2);
    setFieldValue('city', address.city);
    setFieldValue('county', address.county);
    setFieldValue('country', country.id);

    if (onSelectUKAddress) {
      onSelectUKAddress(address);
    }
  };

  return /*#__PURE__*/_react["default"].createElement(_FieldWrapper["default"], (0, _extends2["default"])({
    name: name,
    label: label,
    legend: legend,
    hint: hint
  }, {
    showBorder: true
  }), isUK && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(StyledFieldPostcode, {
    type: "search",
    name: "postcode",
    label: "Postcode",
    required: "Enter postcode",
    maxLength: 10
  }), /*#__PURE__*/_react["default"].createElement(_button["default"], {
    onClick: onSearchClick,
    buttonColour: _govukColours.GREY_3,
    buttonTextColour: _govukColours.BLACK,
    icon: /*#__PURE__*/_react["default"].createElement(_icons.Search, null)
  }, "Find UK address"), error && /*#__PURE__*/_react["default"].createElement(_StatusMessage["default"], null, "Error occurred while searching for an address. Enter the address manually."), addressList && addressList.length > 0 && /*#__PURE__*/_react["default"].createElement(_formGroup["default"], null, /*#__PURE__*/_react["default"].createElement(_select["default"], {
    label: "Select an address",
    onChange: onAddressSelect
  }, addressList.map(function (_ref2, index) {
    var address1 = _ref2.address1;
    return (
      /*#__PURE__*/
      // eslint-disable-next-line react/no-array-index-key
      _react["default"].createElement("option", {
        key: index,
        value: index
      }, address1)
    );
  })))), !isUK && /*#__PURE__*/_react["default"].createElement(StyledFieldPostcode, {
    type: "text",
    name: "postcode",
    label: "Postcode (optional)"
  }), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    type: "text",
    name: "address1",
    label: "Address line 1",
    required: "Enter address line 1"
  }), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    type: "text",
    name: "address2",
    label: "Address line 2 (optional)"
  }), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    type: "text",
    name: "city",
    label: "Town or city",
    required: "Enter town or city"
  }), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    type: "text",
    name: "county",
    label: "County (optional)"
  }), /*#__PURE__*/_react["default"].createElement(_FieldUneditable["default"], {
    name: "country",
    label: "Country"
  }, country.name));
};

FieldAddress.propTypes = {
  name: _propTypes["default"].string.isRequired,
  label: _propTypes["default"].node,
  legend: _propTypes["default"].node,
  hint: _propTypes["default"].node,
  country: _propTypes["default"].shape({
    id: _propTypes["default"].string.isRequired,
    name: _propTypes["default"].string.isRequired
  }).isRequired,
  apiEndpoint: _propTypes["default"].string.isRequired,
  onSelectUKAddress: _propTypes["default"].func
};
FieldAddress.defaultProps = {
  label: null,
  legend: null,
  hint: null,
  onSelectUKAddress: null
};
var _default = FieldAddress;
exports["default"] = _default;