"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = require("lodash");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _govukColours = require("govuk-colours");

var _errorText = _interopRequireDefault(require("@govuk-react/error-text"));

var _label = _interopRequireDefault(require("@govuk-react/label"));

var _input = _interopRequireDefault(require("@govuk-react/input"));

var _labelText = _interopRequireDefault(require("@govuk-react/label-text"));

var _constants = require("@govuk-react/constants");

var _FieldWrapper = _interopRequireDefault(require("./FieldWrapper"));

var _useField2 = _interopRequireDefault(require("../hooks/useField"));

var _useFormContext2 = _interopRequireDefault(require("../hooks/useFormContext"));

var _DateUtils = _interopRequireDefault(require("../../utils/DateUtils"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _templateObject() {
  var data = (0, _taggedTemplateLiteral2["default"])(["\n  ", "\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

var DAY = 'day';
var MONTH = 'month';
var YEAR = 'year';
var FORMAT_LONG = 'LONG';
var StyledInputWrapper = (0, _styledComponents["default"])('div')(_templateObject(), function (props) {
  return props.error && "\n    border-left: ".concat(_constants.BORDER_WIDTH_FORM_ELEMENT_ERROR, " solid ").concat(_govukColours.ERROR_COLOUR, ";\n    margin-right: ").concat(_constants.SPACING.SCALE_3, ";\n    padding-left: ").concat(_constants.SPACING.SCALE_2, ";\n  ");
});
var StyledLabel = (0, _styledComponents["default"])(_label["default"])({
  marginRight: '20px',
  marginBottom: 0
}, function (_ref) {
  var year = _ref.year;
  return {
    width: year ? '70px' : '50px'
  };
});
var StyledList = (0, _styledComponents["default"])('div')({
  display: 'flex'
});

var getValidator = function getValidator(required, format) {
  return function (_ref2) {
    var day = _ref2.day,
        month = _ref2.month,
        year = _ref2.year;
    var isLong = format === FORMAT_LONG;
    var isDateValid = isLong ? _DateUtils["default"].isDateValid(year, month, day) : _DateUtils["default"].isShortDateValid(year, month);
    var isDateEmpty = isLong ? !day && !month && !year : !month && !year;
    return !isDateValid && (!isDateEmpty || required) ? required || 'Enter a valid date' : null;
  };
};

var getDefaultInitialValue = function getDefaultInitialValue(format) {
  return format === FORMAT_LONG ? {
    day: '',
    month: '',
    year: ''
  } : {
    month: '',
    year: ''
  };
};

var FieldDate = function FieldDate(_ref3) {
  var name = _ref3.name,
      label = _ref3.label,
      legend = _ref3.legend,
      hint = _ref3.hint,
      validate = _ref3.validate,
      initialValue = _ref3.initialValue,
      labels = _ref3.labels,
      required = _ref3.required,
      format = _ref3.format;

  var _useField = (0, _useField2["default"])({
    name: name,
    initialValue: initialValue || getDefaultInitialValue(format),
    validate: [getValidator(required, format)].concat((0, _toConsumableArray2["default"])((0, _lodash.castArray)(validate)))
  }),
      value = _useField.value,
      error = _useField.error,
      touched = _useField.touched,
      onBlur = _useField.onBlur;

  var _useFormContext = (0, _useFormContext2["default"])(),
      setFieldValue = _useFormContext.setFieldValue;

  var _onChange = function onChange(valueKey, e) {
    setFieldValue(name, _objectSpread(_objectSpread({}, value), {}, (0, _defineProperty2["default"])({}, valueKey, e.target.value)));
  };

  return /*#__PURE__*/_react["default"].createElement(_FieldWrapper["default"], {
    name: name,
    label: label,
    legend: legend,
    hint: hint,
    error: error
  }, /*#__PURE__*/_react["default"].createElement(StyledInputWrapper, {
    error: error
  }, error && /*#__PURE__*/_react["default"].createElement(_errorText["default"], null, error), /*#__PURE__*/_react["default"].createElement(StyledList, null, format === FORMAT_LONG && /*#__PURE__*/_react["default"].createElement(StyledLabel, null, /*#__PURE__*/_react["default"].createElement(_labelText["default"], null, labels.day), /*#__PURE__*/_react["default"].createElement(_input["default"], {
    id: "".concat(name, ".day"),
    name: "".concat(name, ".day"),
    error: touched && error,
    type: "number",
    value: value.day,
    onChange: function onChange(e) {
      return _onChange(DAY, e);
    },
    onBlur: onBlur
  })), /*#__PURE__*/_react["default"].createElement(StyledLabel, null, /*#__PURE__*/_react["default"].createElement(_labelText["default"], null, labels.month), /*#__PURE__*/_react["default"].createElement(_input["default"], {
    id: "".concat(name, ".month"),
    name: "".concat(name, ".month"),
    error: touched && error,
    type: "number",
    value: value.month,
    onChange: function onChange(e) {
      return _onChange(MONTH, e);
    },
    onBlur: onBlur
  })), /*#__PURE__*/_react["default"].createElement(StyledLabel, {
    year: true
  }, /*#__PURE__*/_react["default"].createElement(_labelText["default"], null, labels.year), /*#__PURE__*/_react["default"].createElement(_input["default"], {
    id: "".concat(name, ".year"),
    name: "".concat(name, ".year"),
    error: touched && error,
    type: "number",
    value: value.year,
    onChange: function onChange(e) {
      return _onChange(YEAR, e);
    },
    onBlur: onBlur
  })))));
};

FieldDate.propTypes = {
  name: _propTypes["default"].string.isRequired,
  label: _propTypes["default"].node,
  legend: _propTypes["default"].node,
  hint: _propTypes["default"].string,
  required: _propTypes["default"].string,
  format: _propTypes["default"].string,
  validate: _propTypes["default"].oneOfType([_propTypes["default"].func, _propTypes["default"].arrayOf(_propTypes["default"].func)]),
  initialValue: _propTypes["default"].shape({
    day: _propTypes["default"].string,
    month: _propTypes["default"].string,
    year: _propTypes["default"].string
  }),
  labels: _propTypes["default"].shape({
    day: _propTypes["default"].string,
    month: _propTypes["default"].string,
    year: _propTypes["default"].string
  })
};
FieldDate.defaultProps = {
  label: null,
  legend: null,
  hint: null,
  required: null,
  validate: null,
  format: FORMAT_LONG,
  initialValue: null,
  labels: {
    day: 'Day',
    month: 'Month',
    year: 'Year'
  }
};
var _default = FieldDate;
exports["default"] = _default;