"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = require("lodash");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _pluralize = _interopRequireDefault(require("pluralize"));

var _constants = require("@govuk-react/constants");

var _icons = require("@govuk-react/icons");

var _unorderedList = _interopRequireDefault(require("@govuk-react/unordered-list"));

var _details = _interopRequireDefault(require("@govuk-react/details"));

var _button = _interopRequireDefault(require("@govuk-react/button"));

var _paragraph = _interopRequireDefault(require("@govuk-react/paragraph"));

var _listItem = _interopRequireDefault(require("@govuk-react/list-item"));

var _useFormContext2 = _interopRequireDefault(require("../hooks/useFormContext"));

var _StatusMessage = _interopRequireDefault(require("../../status-message/StatusMessage"));

var _FieldWrapper = _interopRequireDefault(require("./FieldWrapper"));

var _FieldUneditable = _interopRequireDefault(require("./FieldUneditable"));

var _FieldInput = _interopRequireDefault(require("./FieldInput"));

var _ButtonLink = _interopRequireDefault(require("../../button-link/ButtonLink"));

var _useEntitySearch2 = _interopRequireDefault(require("../../entity-search/useEntitySearch"));

var _useDnbSearch2 = _interopRequireDefault(require("../../entity-search/useDnbSearch"));

var _FormActions = _interopRequireDefault(require("./FormActions"));

var _EntityList = _interopRequireDefault(require("../../entity-search/EntityList"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _templateObject() {
  var data = (0, _taggedTemplateLiteral2["default"])(["\n  list-style-type: disc;\n  padding-left: ", ";\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

var COMPANY_NAME_MIN_LENGTH = 2;
var COMPANY_NAME_MAX_LENGTH = 30;
var StyledUnorderedList = (0, _styledComponents["default"])(_unorderedList["default"])(_templateObject(), _constants.SPACING.SCALE_5);

var validateMinLength = function validateMinLength(minLength) {
  return function (value) {
    return value && value.length < minLength ? "Enter at least ".concat((0, _pluralize["default"])('character', minLength, true)) : null;
  };
};

var validateMaxLength = function validateMaxLength(maxLength) {
  return function (value) {
    return value && value.length > maxLength ? "".concat((0, _pluralize["default"])('character', value.length - maxLength, true), " too long") : null;
  };
};

var FieldDnbCompany = function FieldDnbCompany(_ref) {
  var name = _ref.name,
      label = _ref.label,
      legend = _ref.legend,
      hint = _ref.hint,
      country = _ref.country,
      apiEndpoint = _ref.apiEndpoint,
      queryParams = _ref.queryParams,
      entityRenderer = _ref.entityRenderer,
      onCannotFind = _ref.onCannotFind,
      searchResultsMessage = _ref.searchResultsMessage;

  var _useFormContext = (0, _useFormContext2["default"])(),
      values = _useFormContext.values,
      goBack = _useFormContext.goBack,
      validateForm = _useFormContext.validateForm,
      setIsLoading = _useFormContext.setIsLoading;

  var _useDnbSearch = (0, _useDnbSearch2["default"])(apiEndpoint),
      findCompany = _useDnbSearch.findCompany;

  var _useEntitySearch = (0, _useEntitySearch2["default"])(findCompany),
      onEntitySearch = _useEntitySearch.onEntitySearch,
      searching = _useEntitySearch.searching,
      searched = _useEntitySearch.searched,
      error = _useEntitySearch.error,
      entities = _useEntitySearch.entities;

  function onSearchClick(e) {
    e.preventDefault();
    var noValidationErrors = (0, _lodash.isEmpty)(validateForm());

    if (noValidationErrors) {
      return onEntitySearch((0, _lodash.omitBy)(_objectSpread(_objectSpread({}, queryParams), {}, {
        search_term: values.dnbCompanyName,
        postal_code: values.dnbPostalCode
      }), _lodash.isEmpty));
    }

    return null;
  }

  (0, _react.useEffect)(function () {
    return setIsLoading(searching);
  }, [searching]);
  return /*#__PURE__*/_react["default"].createElement(_FieldWrapper["default"], {
    name: name,
    label: label,
    legend: legend,
    hint: hint
  }, country && /*#__PURE__*/_react["default"].createElement(_FieldUneditable["default"], {
    legend: "Country",
    name: "dnbCountry",
    onChangeClick: goBack
  }, country), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    label: "Company name",
    name: "dnbCompanyName",
    type: "search",
    required: "Enter company name",
    validate: [validateMinLength(COMPANY_NAME_MIN_LENGTH), validateMaxLength(COMPANY_NAME_MAX_LENGTH)]
  }), /*#__PURE__*/_react["default"].createElement(_FieldInput["default"], {
    label: "Company postcode (optional)",
    name: "dnbPostalCode",
    style: {
      width: _constants.WIDTHS['one-third']
    },
    type: "search"
  }), /*#__PURE__*/_react["default"].createElement(_FormActions["default"], null, /*#__PURE__*/_react["default"].createElement(_button["default"], {
    icon: /*#__PURE__*/_react["default"].createElement(_icons.Search, null),
    onClick: onSearchClick
  }, "Find company")), searched && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, entities.length > 0 && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, searchResultsMessage && /*#__PURE__*/_react["default"].createElement(_StatusMessage["default"], null, searchResultsMessage), /*#__PURE__*/_react["default"].createElement(_EntityList["default"], {
    entities: entities,
    entityRenderer: entityRenderer
  })), !error && entities.length === 0 && /*#__PURE__*/_react["default"].createElement(_StatusMessage["default"], null, "No match found. Try one of the options below."), error && /*#__PURE__*/_react["default"].createElement(_StatusMessage["default"], null, "Error occurred while searching for company."), /*#__PURE__*/_react["default"].createElement(_details["default"], {
    summary: "I can't find what I'm looking for"
  }, /*#__PURE__*/_react["default"].createElement(_paragraph["default"], null, "Try:"), /*#__PURE__*/_react["default"].createElement(StyledUnorderedList, null, /*#__PURE__*/_react["default"].createElement(_listItem["default"], null, "checking or removing the postcode"), /*#__PURE__*/_react["default"].createElement(_listItem["default"], null, "removing \"limited\" or \"ltd\""), /*#__PURE__*/_react["default"].createElement(_listItem["default"], null, "checking for spelling errors"), country && /*#__PURE__*/_react["default"].createElement(_listItem["default"], null, "checking if the right country was selected"), /*#__PURE__*/_react["default"].createElement(_listItem["default"], null, "check you're using the company's registered name")), onCannotFind && /*#__PURE__*/_react["default"].createElement(_ButtonLink["default"], {
    onClick: onCannotFind
  }, "I still can't find what I'm looking for"))));
};

FieldDnbCompany.propTypes = {
  name: _propTypes["default"].string.isRequired,
  label: _propTypes["default"].node,
  legend: _propTypes["default"].node,
  hint: _propTypes["default"].node,
  country: _propTypes["default"].string,
  apiEndpoint: _propTypes["default"].string.isRequired,
  queryParams: _propTypes["default"].shape({}),
  entityRenderer: _propTypes["default"].func,
  onCannotFind: _propTypes["default"].func,
  searchResultsMessage: _propTypes["default"].string
};
FieldDnbCompany.defaultProps = {
  label: null,
  legend: null,
  hint: null,
  country: null,
  queryParams: {},
  entityRenderer: undefined,
  onCannotFind: null,
  searchResultsMessage: 'The search results below are verified company records from an external and verified source of company information.'
};
var _default = FieldDnbCompany;
exports["default"] = _default;