"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.flushPromises = exports.changeSelectAndUpdate = exports.changeAndUpdate = exports.getOptionValueByText = exports.withTargetValue = void 0;

var withTargetValue = function withTargetValue(value) {
  return {
    target: {
      value: value
    }
  };
};
/**
 * @function getOptionValueByText
 * @description Finds an `<option>` element with its inner text matching the
 * {text} parameter and returns the value of its `value` attribute.
 * @param {*} wrapper - Enzyme React wrapper
 * @param {String} text - The option text
 */


exports.withTargetValue = withTargetValue;

var getOptionValueByText = function getOptionValueByText(wrapper, text) {
  return wrapper.find('option').find({
    children: text
  }).props().value;
};
/**
 * @function changeAndUpdate
 * @description Simulates the `change` event on the provided {wrapper} with
 * {vaule} as `target.value` and updates (re-renders) the wrapper.
 * @param {*} wrapper - Enzyme React wrapper
 * @param {*} value - The value to be used as `event.target`
 */


exports.getOptionValueByText = getOptionValueByText;

var changeAndUpdate = function changeAndUpdate(wrapper, value) {
  wrapper.simulate('change', withTargetValue(value));
  wrapper.update();
};
/**
 * @function changeSelectAndUpdate
 * @description Finds a `<select>` element in the wrapper, selects the option
 * matching the {text} and updates (re-renders) the wrapper.
 * @param {*} wrapper - Enzyme React wrapper
 * @param {String} text - The option text
 */


exports.changeAndUpdate = changeAndUpdate;

var changeSelectAndUpdate = function changeSelectAndUpdate(wrapper, text) {
  changeAndUpdate(wrapper.find('select'), getOptionValueByText(wrapper, text));
  wrapper.update();
};

exports.changeSelectAndUpdate = changeSelectAndUpdate;

var flushPromises = function flushPromises() {
  return new Promise(function (resolve) {
    setTimeout(resolve, 0);
  });
};

exports.flushPromises = flushPromises;